@@ -17,10 +17,5 @@ You should have received a copy of the GNU General Public License
 along with qdatamatatrix.  If not, see <http://www.gnu.org/licenses/>.
 """
 
-__version__ = '0.1.25'
-
-import os
-from datamatrix.py3compat import *
-# In case we only want to get the version
-if os.environ.get('NO_QTPY', '0') != '1':
-    from qdatamatrix._qdatamatrix import QDataMatrix
+from qdatamatrix._version import __version__
+from qdatamatrix._qdatamatrix import QDataMatrix
